;;
;; x-face-el-init.el
;;
;; Takuo KITAME <kitame@northeye.org>

(setq load-path 
      (cons 
       (concat "/usr/share/" (symbol-name debian-emacs-flavor)
              "/site-lisp/x-face-el")
       load-path))

(autoload 'x-face-encode "x-face"
  "Generate X-Face string(s) from xbm file." t)
(autoload 'x-face-insert "x-face"
  "Insert X-Face fields." t)
(autoload 'x-face-save "x-face"
  "Save X-Face fields to files." t)
(autoload 'x-face-view "x-face"
  "View X-Face fields." t)
(autoload 'x-face-ascii-view "x-face"
  "View X-Face fields as ascii pictures." t)

(if (featurep 'xemacs)
		(progn
			(autoload 'x-face-xmas-display-x-face "x-face"
				"Display X-Face fields as XEmacs-glyph." t)
			(autoload 'x-face-xmas-force-display-x-face "x-face"
				"Display X-Face fields compulsorily as XEmacs glyph." t)
			(autoload 'x-face-xmas-remove-x-face-glyph "x-face"
						"Remove X-Face images and some text-properties." t)
			)
	)

(require 'x-face)

(setq x-face-compressor-program-list
      '((gzip ".gz" "gzip" "-c9" "GZIPping" "gzip" "-cd" "GUNZIPping")
				(bzip2 ".bz2" "bzip2" "-f" "BZIPping" "bzip2" "-d" "BUNZIPping")))

(setq x-face-compface-program "compface")
(setq x-face-uncompface-program "uncompface")

(setq x-face-save-or-view-method-alist
      '(
	(gnus-summary-mode
	 . (gnus-summary-show-article
	    x-face-find-gnus-article-buffer
	    gnus-summary-show-article))
	(gnus-Subject-mode
	 . (gnus-Subject-show-article
	    x-face-find-gnus-article-buffer
	    gnus-Subject-show-article))
	(wl-summary-mode
	 . (x-face-wl-get-article
	    x-face-extracted-headers-buffer))
	(cmail-summary-mode
	 . (x-face-cmail-get-article
	    x-face-extracted-headers-buffer))
	(mh-folder-mode
	 . (x-face-mh-get-article
	    x-face-extracted-headers-buffer))
	(vm-summary-mode
	 . (x-face-vm-get-all-headers
	    x-face-extracted-headers-buffer))
	(mew-summary-mode
	 . (x-face-mew-get-article
	    x-face-extracted-headers-buffer))
	(mew-virtual-mode
	 . (x-face-mew-get-article
	    x-face-extracted-headers-buffer))
	))

(mapcar
 (function (lambda (hook) (add-hook hook 'x-face-define-menu)))
 '(gnus-message-setup-hook 
	 gnus-summary-mode-hook
   wl-summary-mode-hook
	 wl-mail-setup-hook
   cmail-summary-mode-hook
   mail-setup-hook
   mh-folder-mode-hook
	 mh-letter-mode-hook
   rmail-mode-hook
	 vm-summary-mode-hook
   mew-draft-mode-hook
	 mew-summary-mode-hook
	 mew-virtual-mode-hook))

(if (featurep 'xemacs) 
		(and window-system
				 (progn
					 ;; for gnus
					 (setq gnus-article-display-hook nil)
					 (x-face-xmas-replace-highlight-headers)
					 (x-face-xmas-replace-x-face-function-for-semi)
					 ;; for Wanderlust
					 (autoload 'x-face-xmas-wl-display-x-face "x-face" nil t)
					 (setq wl-highlight-x-face-func
								 'x-face-xmas-wl-display-x-face)
					 ;; for Mew
					 (autoload 'x-face-xmas-mew-display-x-face "x-face" nil t)
					 (setq mew-use-highlight-x-face-function 'x-face-xmas-mew-display-x-face)
					 ;; inline display in draft
					 (setq x-face-xmas-auto-image t)
					 ;; for SEMI
					 (add-hook 'mime-edit-translate-hook
										 'x-face-xmas-remove-x-face-glyph)
					 )))

(require 'x-face)

